@@ -7,7 +7,7 @@ def mongo_credentials(environment):
     """
     credentials = {
         "uri": os.getenv("MONGO_URI_CONN") or "mongodb://localhost:27017/test",
-        "ssl": os.getenv("MONGO_SSL") or True
+        "ssl": os.getenv("MONGO_SSL") or False
     }
 
     if not credentials["uri"]:
@@ -29,7 +29,7 @@ def neo4j_credentials(environment):
         "port": os.getenv("BOT_NEO4J_PORT") or 7687,
         "user": os.getenv("BOT_NEO4J_USER") or 'neo4j',
         "db_name": os.getenv("BOT_NEO4J_NAME") or 'neo4j',
-        "passwd": os.getenv("BOT_NEO4J_PASSWORD") or 'alvarole3552'
+        "passwd": os.getenv("BOT_NEO4J_PASSWORD") or 'neo4j'
 
     }
 
